Crate libipt

Modules

asid
block
The block layer provides a simple API for iterating over blocks of sequential instructions in execution order.
enc_dec_builder
The pt_config structure defines an Intel Processor Trace (Intel PT) encoder or decoder configuration.
error
The library uses a single error enum for all layers.
event
The event layer deals with packet combinations that encode higher-level events.
image
insn
The instruction flow layer provides a simple API for iterating over instructions in execution order.
packet
This layer deals with Intel PT packet encoding and decoding.
status

Structs

Version
The library version.